==> rs4-0.3.11-py3-none-any.whl: rs4/protocols/sock/impl/grpc/producers.py <==
from .....misc import compressors
from collections.abc import Iterable
import struct

def serialize (msg, use_compress = True):
	compressed = 0
	serialized = msg.SerializeToString ()
	if use_compress and len (serialized) > 2048:
		serialized = self.compressor.compress (serialized) + self.compressor.flush ()
		compressed = 1
	return struct.pack ("!B", compressed) + struct.pack ("!I", len (serialized)) + serialized

class grpc_producer:
	def __init__ (self, message = None, use_compress = False):
		self.closed = False
		self.use_compress = use_compress
		self.compressor = compressors.GZipCompressor ()
		self.message = message
		self.serialized = []
		self.content_length = 0

	def get_headers (self):
		headers = []
		if self.use_compress:
			headers.append (("grpc-encoding", "gzip"))
		return headers

	def get_size (self):
		return self.content_length or -1

	def get_content_length (self):
		if self.closed:
			return self.content_length

	def send (self, msg):
		self.message.send (msg)

	def serialize (self, msg):
		s = serialize (msg, self.use_compress)
		self.serialized.append (s)
		self.content_length += len (s)
		return s

	def get_payload (self):
		return b"".join (self.serialized)

	def more (self):
		if self.exhausted ():
			return b""

		if not isinstance (self.message, Iterable):
			msg = self.serialize (self.message)
			self.close ()
			return msg

		try:
			msg = next (self.message)
			return self.serialize (msg)
		except StopIteration:
			self.close ()
			return b""

	def exhausted (self):
		return self.closed and not self.message

	def close (self):
		self.content_length = 0
		self.closed = True
		self.message = None

==> rs4-0.3.19.1-py3-none-any.whl: rs4/protocols/sock/impl/grpc/producers.py <==
from .....misc import compressors
from collections.abc import Iterable
import struct

def serialize (msg, use_compress = True, compressor = None):
	compressed = 0
	serialized = msg.SerializeToString ()
	if use_compress and len (serialized) > 2048:
		serialized = compressor.compress (serialized) + compressor.flush ()
		compressed = 1
	return struct.pack ("!B", compressed) + struct.pack ("!I", len (serialized)) + serialized

class grpc_producer:
	def __init__ (self, message = None, use_compress = False):
		self.closed = False
		self.use_compress = use_compress
		self.compressor = compressors.GZipCompressor ()
		self.message = message
		self.serialized = []
		self.content_length = 0

	def get_headers (self):
		headers = []
		if self.use_compress:
			headers.append (("grpc-encoding", "gzip"))
		return headers

	def get_size (self):
		return self.content_length or -1

	def get_content_length (self):
		if self.closed:
			return self.content_length

	def send (self, msg):
		self.message.send (msg)

	def serialize (self, msg):
		s = serialize (msg, self.use_compress, self.compressor)
		self.serialized.append (s)
		self.content_length += len (s)
		return s

	def get_payload (self):
		return b"".join (self.serialized)

	def more (self):
		if self.exhausted ():
			return b""

		if not isinstance (self.message, Iterable):
			msg = self.serialize (self.message)
			self.close ()
			return msg

		try:
			msg = next (self.message)
			return self.serialize (msg)
		except StopIteration:
			self.close ()
			return b""

	def exhausted (self):
		return self.closed and not self.message

	def close (self):
		self.content_length = 0
		self.closed = True
		self.message = None
